#
# spec file for package PackageKit-Qt
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define QtVersion 4
%if %{QtVersion} == 4
BuildRequires:  libqt4-devel
%define libpk   libpackagekitqt4-0
%endif
%if %{QtVersion} == 5
%define libpk   libpackagekitqt5-0
%endif

Name:           PackageKit-Qt
%define _name   PackageKit-Qt
Version:        0.9.5
Release:        3.5
Summary:        Simple software installation management software
License:        LGPL-2.1+
Group:          System/Daemons
Url:            http://packagekit.org/
Source:         http://www.freedesktop.org/software/PackageKit/releases/%{_name}-%{version}.tar.xz
Source99:       pre_checkin.sh
BuildRequires:  PackageKit-devel >= %{version}
BuildRequires:  cmake
BuildRequires:  kde4-filesystem
%if %{QtVersion} == 4
BuildRequires:  libqt4-devel
%endif
%if %{QtVersion} == 5
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Sql)
%endif

%description
PackageKit is a system designed to make installing and updating
software on your computer easier.  The primary design goal is to unify
all the software graphical tools used in different distributions, and
use some of the latest technology like PolicyKit to make the process
suck less.

%package -n %{libpk}
Summary:        Simple software installation management software
Group:          System/Libraries

%description -n %{libpk}
PackageKit is a system designed to make installing and updating
software on your computer easier.  The primary design goal is to unify
all the software graphical tools used in different distributions, and
use some of the latest technology like PolicyKit to make the process
suck less.

%package devel
Summary:        Simple software installation management software
Group:          Development/Libraries/C and C++
Requires:       %{libpk} = %{version}
%if %{QtVersion} == 4
Provides:       libpackagekit-qt2-devel = %{version}
Obsoletes:      libpackagekit-qt2-devel < %{version}
%endif

%description devel
PackageKit is a system designed to make installing and updating
software on your computer easier.  The primary design goal is to unify
all the software graphical tools used in different distributions, and
use some of the latest technology like PolicyKit to make the process
suck less.

%prep
%setup -q -n %{_name}-%{version}

%build
mkdir build
cd build
cmake \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
%if %{QtVersion} == 5
  -DUSE_QT5=ON \
%endif
  ..
make %{?smp_mflags}

%install
cd build
%make_install

%post -n %{libpk} -p /sbin/ldconfig

%postun -n %{libpk} -p /sbin/ldconfig

%files -n %{libpk}
%defattr(-,root,root)
%doc COPYING NEWS AUTHORS
%{_libdir}/libpackagekitqt?.so.*

%files devel
%defattr(-,root,root)
%doc TODO MAINTAINERS
%{_libdir}/libpackagekitqt?.so
%{_libdir}/cmake/packagekitqt?/
%{_libdir}/pkgconfig/packagekitqt?.pc
%{_includedir}/packagekitqt?/

%changelog
* Wed Nov 19 2014 zaitor@opensuse.org
- Update to version 0.9.5:
  + New Features: Add operator== to bitfield.
  + Bugfixes:
  - Deprecate ::packageIcon methods.
  - Disable namespacing and classes names on the generated
    interfaces.
  - Don't assume the target is packagekitqt5.
  - Fix compilation due to not-set cmake variable.
  - Fix documentation.
  - Fix QPK include dir in cmake module.
  - Properly export cmake targets.
  - Remove daemon proxy conection to changed().
  - Remove RoleUpgradeSystem as it's not supported in 0.9.x
    anymore.
  - Remove the metatype registration for Transaction types.
  - Support RPATH by default.
  - Use GNUInstallDirs to determine most of used variables.
  - Use "PackageKit" as the include namespace rather than the
    library name.
- Drop PackageKit-Qt-ff-7248b030c0.patch and
  0001-Use-GNUInstallDirs-to-determine-most-of-used-variabl.patch:
  Fixed upstream/No longer needed.
* Fri Oct  3 2014 dimstar@opensuse.org
- Build PackageKit-Qt5 variant:
  + Add pre_checkin.sh to help keep Qt4 and Qt5 variants in sync.
  + Introduce QtVersion defines to distinguish between Qt4 and Qt5
    build.
  + Only BuildRequire libqt4-devel when built for Qt4.
  + In case of Qt5 builds, add:
  - -DUSE_QT5=ON parameter to cmake.
  - pkgconfig(Qt5Core), pkgconfig(Qt5DBus) and pkgconfig(Qt5Sql)
    BuildRequires.
* Thu Sep 18 2014 hrvoje.senjan@gmail.com
- Add
  0001-Use-GNUInstallDirs-to-determine-most-of-used-variabl.patch:
  Use GNUinstallDirs to determine relevant destination directories.
  Also removed unused vars.
- Pass only install prefix, the above patch takes care of the
  libdir.
* Thu Sep 18 2014 dimstar@opensuse.org
- Add PackageKit-Qt-ff-7248b030c0.patch: Fast forward to git
  commit 7248b030c0, fixing build with PackageKit 1.0.0.
- Rename libpackagekit-qt2-6 subpackage to libpackagekitqt4-0,
  following upstreams soname bump.
- Adust Requires in -devel package accordingly.
* Wed Sep 10 2014 dimstar@opensuse.org
- Update to version 0.9.2:
  + Notes:
  - Update to new PK API 0.9.
  - Applied a series of patches to port to Qt5.
  + New Features:
  - Add GetDetailsLocal, GetFilesLocal and RepoRemove.
  - Make use of DBus Properties changed to make less blocking
    calls.
  + Bugfixes:
  - Allow for Details to be empty constructed.
  - Cleaned include directive.
  - Finish the API changes to get rid of blocking calls.
  - Fix CMake var names for both Qt versions.
  - Fix libdir path.
  - Fix reply signature for Transaction methods.
  - Improve object handlying.
  - I think the API level should be hidden from libname.
  - Keep only one transaction flags, which is unlikely to change.
  - PackageKit doesn't has a changed signal anymore.
  - Properly delete private data on daemon as DaemonPrivate is
    not a QObject.
  - Properly handle new Details signal.
  - Properly init some Daemon values.
  - Queue signals so that all transaction properties are
    available when needed.
  - Remove debug info.
  - Update Roles enum, remove Provides enum, and fix some docs
    typos.
- Drop PackageKit-Qt-libdir-references.patch: fixed upstream.
* Fri Sep 20 2013 alarrosa@suse.com
- Add PackageKit-Qt-libdir-references.patch: Fix the installed
  packagekit-qt2-config.cmake file to have the correct link to the
  library by keeping CMAKE_INSTALL_LIBDIR as a relative path and
  the .pc file to have a valid path to $libdir.
* Fri May 10 2013 cgiboudeaux@gmx.com
- Update to 0.8.8
  + New Features:
  - Adding Provides property to Daemon.
  - Adding some Meta information.
  - Adds the transactionFlags to the Transaction class.
  - Add TransactionFlags registration.
  - Implement connectNotify and disconnectNotify.
  + Bugfixes:
  - Add missing declare enums.
  - Fix searchGroups() be iterating over the flaged values.
  - Ignore Interface isValid() check.
  - Improve error handling and make it easier for QML use it.
  - Make sure we set an error if we fail to contact PackageKit.
  - Use the correct version of the LGPL library.
- Drop 0001-upstream-license-correction.patch: fixed upstream.
- Rename libpackagekit-qt2-5 subpackage to libpackagekit-qt2-6,
  following upstreams soname change.
* Mon Mar 11 2013 coolo@suse.com
- add rename provides for old devel package
* Tue Jan 22 2013 tittiatcoke@gmail.com
- Add 0001-upstream-license-correction.patch: Update COPYING file
  to reflect LGPL-2.1. The GPL-3.0 COPYING file was just the
  default injected one by autotools, if none is explicitly given.
- Udpate License tag LGPL-2.1 (from LGPL-2.0, which was what the
  file headers indicated).
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Initial package, version 0.8.7:
  + This is the first release of Packagekit-Qt which has been split
    out of the main PackageKit project. This project is decoupled
    from the main PackageKit project from  this point onwards and
    does not subscribe to the same API and ABI promises of
    PackageKit.
